// Copyright (c) Project Jupyter Contributors
// Distributed under the terms of the Modified BSD License.
/**
 * A group of toggle buttons, one of which can be selected.
 */
export class ButtonGroup {
    constructor(buttons) {
        this._buttons = buttons;
        this._activeIndex = 0;
        // Any time a button's state changes, set all other buttons to not toggled.
        const updateActive = (button, args) => {
            if (args.name === 'toggled' && args.newValue === true) {
                this.activeIndex = this._buttons.indexOf(button);
            }
        };
        buttons.forEach(button => {
            button.stateChanged.connect(updateActive);
        });
    }
    get activeIndex() {
        return this._activeIndex;
    }
    set activeIndex(newValue) {
        let oldValue = this._activeIndex;
        if (oldValue !== newValue) {
            this._buttons.forEach((button, j) => {
                button.toggled = j === newValue;
            });
        }
    }
}
