// Copyright (c) Project Jupyter Contributors
// Distributed under the terms of the Modified BSD License.
import { Signal } from '@phosphor/signaling';
export class Disposable {
    constructor() {
        this._isDisposed = false;
        this._disposed = new Signal(this);
    }
    /**
     * Dispose of the button.
     *
     * #### Notes
     * It is unsafe to use the button after it has been disposed.
     *
     * All calls made to this method after the first are a no-op.
     */
    dispose() {
        // Do nothing if the widget is already disposed.
        if (this.isDisposed) {
            return;
        }
        this._isDisposed = true;
        this._disposed.emit(undefined);
        // Clear the extra data associated with the widget.
        Signal.clearData(this);
    }
    /**
     * Test whether the widget has been disposed.
     */
    get isDisposed() {
        return this._isDisposed;
    }
    /**
     * A signal emitted when the widget is disposed.
     */
    get disposed() {
        return this._disposed;
    }
}
